@@ -3,5 +3,5 @@
                       fields="Version")
     packageStartupMessage(paste(pkgname, Bclimver))
     packageStartupMessage("Welcome to Bclim. Type help(Bclim) to get started.")
-    packageStartupMessage("See http://mathsci.ucd.ie/~parnell_a/Bclim.html for updates, bugs and a tutorial.")
+    packageStartupMessage("See http://mathsci.ucd.ie/~parnell_a/Rpack/Bclim.htm for updates, bugs and a tutorial.")
 }
